@@ -5,7 +5,6 @@ from pyf.componentized.configuration.fields import SingleSelectField, InputField
     TextAreaField, BooleanField
     
 from py3o.template import Template
-from py3o.renderclient import RenderClient
 import logging
 import itertools
 
@@ -84,11 +83,16 @@ class OOoWriter(MultipleFileWriter):
         self.config_node = config_node
         self.id = component_id
         
-    def render(self, filename, rendering_options):
+    def render(self, filename, rendering_options, key):
+        from py3o.renderclient import RenderClient
         client = RenderClient(rendering_options.get('host', 'localhost'),
                               int(rendering_options.get('port', '8994')))
+        
         output_filename = self.get_output_filename(
-                                        rendering_options['target_filename'])
+                                        self.prepare_filename(
+                                                    rendering_options['target_filename'], key=key
+                                                    ))
+        
         client.render(filename, output_filename, rendering_options['format'])
 
     def write(self, values, key, output_filename, target_filename):
@@ -114,7 +118,8 @@ class OOoWriter(MultipleFileWriter):
                     datas = values,
                     first_packet = first_packet,
                     get_config_key = self.get_config_key,
-                    key=key))
+                    key=key
+        ))
 
         for status in status_flow:
             if status:
@@ -127,7 +132,7 @@ class OOoWriter(MultipleFileWriter):
         if do_rendering:
             self.message_callback("ODT generation complete, trying to render.")
             try:
-                self.render(output_filename, rendering_options)
+                self.render(output_filename, rendering_options, key=key)
             except Exception, e:
                 logging.exception(e)
                 self.message_callback("Rendering failed: %s" % e, message_type="error")
